==> dmn-0.10.0-sources.jar: org/powerflows/dmn/engine/evaluator/entry/mode/provider/EvaluationModeProviderFactory.java <==
/*
 * Copyright (c) 2018-present PowerFlows.org - all rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.powerflows.dmn.engine.evaluator.entry.mode.provider;

import org.powerflows.dmn.engine.model.decision.EvaluationMode;

import java.util.EnumMap;

public class EvaluationModeProviderFactory {

    private final EnumMap<EvaluationMode, EvaluationModeProvider> factories = new EnumMap<>(EvaluationMode.class);

    public EvaluationModeProviderFactory() {
        factories.put(EvaluationMode.BOOLEAN, new BooleanEvaluationModeProvider());
        factories.put(EvaluationMode.INPUT_COMPARISON, new InputComparisonEvaluationModeProvider());
    }

    public EvaluationModeProvider getInstance(final EvaluationMode evaluationMode) {
        final EvaluationModeProvider evaluationModeProvider = factories.get(evaluationMode);

        if (evaluationModeProvider == null) {
            throw new IllegalArgumentException("Unknown evaluation mode " + evaluationMode);
        }

        return evaluationModeProvider;
    }
}

==> dmn-1.0.0-sources.jar: org/powerflows/dmn/engine/evaluator/entry/mode/provider/EvaluationModeProviderFactory.java <==
/*
 * Copyright (c) 2018-present PowerFlows.org - all rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.powerflows.dmn.engine.evaluator.entry.mode.provider;

import org.powerflows.dmn.engine.model.decision.EvaluationMode;

import java.util.EnumMap;

/**
 * Factory for entry evaluation mode providers.
 * Instantiates and caches {@link BooleanEvaluationModeProvider} and {@link InputComparisonEvaluationModeProvider}
 */
public class EvaluationModeProviderFactory {

    private final EnumMap<EvaluationMode, EvaluationModeProvider> factories = new EnumMap<>(EvaluationMode.class);

    public EvaluationModeProviderFactory() {
        factories.put(EvaluationMode.BOOLEAN, new BooleanEvaluationModeProvider());
        factories.put(EvaluationMode.INPUT_COMPARISON, new InputComparisonEvaluationModeProvider());
    }

    public EvaluationModeProvider getInstance(final EvaluationMode evaluationMode) {
        final EvaluationModeProvider evaluationModeProvider = factories.get(evaluationMode);

        if (evaluationModeProvider == null) {
            throw new IllegalArgumentException("Unknown evaluation mode " + evaluationMode);
        }

        return evaluationModeProvider;
    }
}
